# This file is part of SSHare.
#
# SSHare is free software: you can redistribute it and/or modify it under the terms of
# the GNU General Public License as published by the Free Software Foundation,
# either version 3 of the License, or (at your option) any later version.
#
# SSHare is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY
# or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
# more details.
#
# You should have received a copy of the GNU General Public License along with
# SSHare. If not, see <https://www.gnu.org/licenses/>. 

import getpass
import importlib.util
import os
import os.path
import pyclip
import time
import subprocess
import sys

def main():
    config = Config()

    file = _latest("/home/gnarwhal/Pictures/Screenshots")
    print(f"=> Selected file '{file}'")

    id = time.time_ns()
    (_, extension) = os.path.splitext(file)
    target_file_name = f"{id}{extension}"
    target_destination = f"{config.ssh_user}@{config.ssh_target}:{config.ssh_dir}/{target_file_name}"
    print(f"=> Uploading to '{target_destination}'")
    process = subprocess.run([
        "scp",
        f"-P {config.ssh_port}",
        file,
        target_destination,
    ])
    if process.returncode != 0:
        print("=> Error: failed to upload file")
        sys.exit(1)

    target_url = f"https://{config.ssh_target}/sshare/{target_file_name}"
    pyclip.copy(target_url)
    print(f"=> File available at '{target_url}'")

    sys.exit(0)


def _latest(directory, key=os.path.getmtime):
    files         = map(lambda file: f"{directory}/{file}", os.listdir(directory))
    selection     = next(files)
    selection_key = key(selection)
    for file in files:
        new_key = key(file)
        if new_key > selection_key:
            selection     = file
            selection_key = key
    return selection
    

class Config:
    def __init__(self):
        self.ssh_port   = 2222
        self.ssh_user   = getpass.getuser()
        self.ssh_target = "monodon.me"
        self.ssh_dir    = "/srv/gnarwhal/sshare"
